==> GenomicFeatures_1.2.3.zip: GenomicFeatures/doc/examples.R <==
###################################################
### chunk number 1: SetUp Session
###################################################
#line 36 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
library(rtracklayer)
session <- browserSession()


###################################################
### chunk number 2: Choose Genome
###################################################
#line 47 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
head(ucscGenomes())


###################################################
### chunk number 3: Set Genome
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
genome(session) <- "hg18"


###################################################
### chunk number 4: Check Available Tracks
###################################################
#line 64 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
head(trackNames(session))


###################################################
### chunk number 5: Simple Query eval=FALSE
###################################################
## #line 76 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
## query <- ucscTableQuery(session, "refGene")


###################################################
### chunk number 6: Get Table eval=FALSE
###################################################
## #line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
## head(getTable(query))


###################################################
### chunk number 7: Access SNPs
###################################################
#line 117 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
query <- ucscTableQuery(session, "snp130",
                        GenomicRanges(57795963, 57815592, "chr12"))
head(getTable(query)) 


###################################################
### chunk number 8: SessionInfo
###################################################
#line 145 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpB4t6MC/R.INSTALL694b369e/GenomicFeatures/inst/doc/examples.Rnw"
sessionInfo()

==> GenomicFeatures_1.4.5.zip: GenomicFeatures/doc/examples.R <==
### R code from vignette source 'examples.Rnw'

###################################################
### code chunk number 1: SetUp Session
###################################################
library(rtracklayer)
session <- browserSession()


###################################################
### code chunk number 2: Choose Genome
###################################################
head(ucscGenomes())


###################################################
### code chunk number 3: Set Genome
###################################################
genome(session) <- "hg18"


###################################################
### code chunk number 4: Check Available Tracks
###################################################
head(trackNames(session))


###################################################
### code chunk number 5: Simple Query (eval = FALSE)
###################################################
## query <- ucscTableQuery(session, "refGene")


###################################################
### code chunk number 6: Get Table (eval = FALSE)
###################################################
## head(getTable(query))


###################################################
### code chunk number 7: Access SNPs
###################################################
query <- ucscTableQuery(session, "snp130",
                        GenomicRanges(57795963, 57815592, "chr12"))
head(getTable(query)) 


###################################################
### code chunk number 8: SessionInfo
###################################################
sessionInfo()
